@@ -32,7 +32,7 @@ class Dcim(object):
         """Delete region
 
         :param region_name: Region to delete
-        :return: bool True if succesful otherwase delete exception
+        :return: bool True if succesful otherwise raise exception
         """
         try:
             region_id = self.get_regions(name=region_name)[0]['id']
@@ -40,6 +40,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('region: {}'.format(region_name)) from None
         return self.netbox_con.delete('/dcim/regions/', region_id)
 
+    def delete_region_by_id(self, region_id):
+        """Delete region
+
+        :param region_id: Region to delete
+        :return: bool True if succesful otherwise raise delete exception
+        """
+        return self.netbox_con.delete('/dcim/regions/', region_id)
+
     def update_region(self, region_name, **kwargs):
         """
 
@@ -53,6 +61,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('region: {}'.format(region_name)) from None
         return self.netbox_con.patch('/dcim/regions/', region_id, **kwargs)
 
+    def update_region_id(self, region_id, **kwargs):
+        """Update Region by id
+
+        :param region_id: Region to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/regions/', region_id, **kwargs)
+
     def get_sites(self, **kwargs):
         """Returns all available sites"""
         return self.netbox_con.get('/dcim/sites/', **kwargs)
@@ -80,6 +97,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('site: {}'.format(site_name)) from None
         return self.netbox_con.delete('/dcim/sites/', site_id)
 
+    def delete_site_by_id(self, site_id):
+        """Delete site
+
+        :param site_id: Site to delete
+        :return: bool True if succesful otherwase raise exception
+        """
+        return self.netbox_con.delete('/dcim/sites/', site_id)
+
     def update_site(self, site_name, **kwargs):
         """
 
@@ -93,6 +118,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('site: {}'.format(site_name)) from None
         return self.netbox_con.patch('/dcim/sites/', site_id, **kwargs)
 
+    def update_site_by_id(self, site_id, **kwargs):
+        """Update a site by id
+
+        :param site_id: Site to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/sites/', site_id, **kwargs)
+
     def get_racks(self, **kwargs):
         """Returns all available racks"""
         return self.netbox_con.get('/dcim/racks/', **kwargs)
@@ -124,10 +158,18 @@ class Dcim(object):
             raise exceptions.NotFoundException('rack: {}'.format(rack_name)) from None
         return self.netbox_con.delete('/dcim/racks/', rack_id)
 
+    def delete_rack_by_id(self, rack_id):
+        """Delete rack
+
+        :param rack_id: Rack to delete
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.delete('/dcim/racks/', rack_id)
+
     def update_rack(self, rack_name, **kwargs):
         """
 
-        :param rack_name: rack_name name to update
+        :param rack_name: Rack to update
         :param kwargs: requests body dict
         :return: bool True if successful otherwise raise UpdateException
         """
@@ -137,6 +179,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('rack: {}'.format(rack_name)) from None
         return self.netbox_con.patch('/dcim/racks/', rack_id, **kwargs)
 
+    def update_rack_by_id(self, rack_id, **kwargs):
+        """
+
+        :param rack_id: Rack group to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/racks/', rack_id, **kwargs)
+
     def get_rack_groups(self, **kwargs):
         """Returns all available rack groups"""
         return self.netbox_con.get('/dcim/rack-groups/', **kwargs)
@@ -169,10 +220,18 @@ class Dcim(object):
             raise exceptions.NotFoundException('rack-group: {}'.format(name)) from None
         return self.netbox_con.delete('/dcim/rack-groups/', rack_group_id)
 
+    def delete_rack_group_by_id(self, rack_group_id):
+        """Delete rack group
+
+        :param rack_group_id: Rack group to delete
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.delete('/dcim/rack-groups/', rack_group_id)
+
     def update_rack_group(self, name, **kwargs):
         """
 
-        :param name: Rack group name to update
+        :param name: Rack group to update
         :param kwargs: requests body dict
         :return: bool True if successful otherwise raise UpdateException
         """
@@ -182,6 +241,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('rack group: {}'.format(name)) from None
         return self.netbox_con.patch('/dcim/rack-groups/', rack_group_id, **kwargs)
 
+    def update_rack_group_by_id(self, rack_group_id, **kwargs):
+        """
+
+        :param rack_group_id: Rack group to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/rack-groups/', rack_group_id, **kwargs)
+
     def get_devices(self, **kwargs):
         """Get all devices"""
         return self.netbox_con.get('/dcim/devices/', **kwargs)
@@ -230,7 +298,7 @@ class Dcim(object):
         return self.netbox_con.post('/dcim/devices/', required_fields, **kwargs)
 
     def delete_device(self, device_name):
-        """Delete device by name
+        """Delete device by device name
 
         :param device_name: Device to delete
         :return: bool True if successful otherwise raise DeleteException
@@ -241,6 +309,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('device: {}'.format(device_name)) from None
         return self.netbox_con.delete('/dcim/devices/', device_id)
 
+    def delete_device_by_id(self, device_id):
+        """Delete device
+
+        :param device_id: Device to delete
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.delete('/dcim/devices/', device_id)
+
     def update_device(self, device_name, **kwargs):
         """Update device by device name
 
@@ -251,6 +327,15 @@ class Dcim(object):
         device_id = self.get_devices(name=device_name)[0]['id']
         return self.netbox_con.patch('/dcim/devices/', device_id, **kwargs)
 
+    def update_device_by_id(self, device_id, **kwargs):
+        """Update device by id
+
+        :param device_id: Device to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise UpdateException
+        """
+        return self.netbox_con.patch('/dcim/devices/', device_id, **kwargs)
+
     def get_device_types(self, **kwargs):
         """Get devices by device type"""
         return self.netbox_con.get('/dcim/device-types/', **kwargs)
@@ -270,7 +355,7 @@ class Dcim(object):
     def update_device_type(self, device_type, **kwargs):
         """Update device type
 
-        :param device_type: device-type name to update
+        :param device_type: device-type to update
         :param kwargs: requests body dict
         :return: bool True if successful otherwise raise UpdateException
         """
@@ -280,6 +365,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('device-type: {}'.format(device_type)) from None
         return self.netbox_con.patch('/dcim/device-types/', device_type_id, **kwargs)
 
+    def update_device_type_by_id(self, device_type_id, **kwargs):
+        """Update device type
+
+        :param device_type_id: device-type to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise UpdateException
+        """
+        return self.netbox_con.patch('/dcim/device-types/', device_type_id, **kwargs)
+
     def delete_device_type(self, model_name):
         """Delete device type
 
@@ -292,6 +386,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('device-type: {}'.format(model_name)) from None
         return self.netbox_con.delete('/dcim/device-types/', device_type_id)
 
+    def delete_device_type_by_id(self, device_type_id):
+        """Delete device type
+
+        :param device_type_id: Id of the device-type to delete
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.delete('/dcim/device-types/', device_type_id)
+
     def get_device_roles(self, **kwargs):
         """Return all the device roles"""
         return self.netbox_con.get('/dcim/device-roles/', **kwargs)
@@ -311,7 +413,7 @@ class Dcim(object):
     def update_device_role(self, device_role, **kwargs):
         """Update device role
 
-        :param device_role: device-type name to update
+        :param device_role: device-role to update
         :param kwargs: requests body dict
         :return: bool True if successful otherwise raise UpdateException
         """
@@ -321,6 +423,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('device-role: {}'.format(device_role)) from None
         return self.netbox_con.patch('/dcim/device-roles/', device_role_id, **kwargs)
 
+    def update_device_role_by_id(self, device_role_id, **kwargs):
+        """Update device role
+
+        :param device_role_id: device role to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/device-roles/', device_role_id, **kwargs)
+
     def delete_device_role(self, device_role):
         """Delete device by device role
 
@@ -333,6 +444,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('device-role: {}'.format(device_role)) from None
         return self.netbox_con.delete('/dcim/device-roles/', device_role_id)
 
+    def delete_device_role_by_id(self, device_role_id):
+        """Delete device role
+
+        :param device_role_id: device role to delete
+        :return: bool True if successful otherwise raise DeleteException
+        """
+        return self.netbox_con.delete('/dcim/device-roles/', device_role_id)
+
     def get_manufacturers(self, **kwargs):
         """Return all manufactures"""
         return self.netbox_con.get('/dcim/manufacturers/', **kwargs)
@@ -361,6 +480,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('manufacturer: {}'.format(manufacturer_name)) from None
         return self.netbox_con.patch('/dcim/manufacturer/', manufacturer_id, **kwargs)
 
+    def update_manufacturer_by_id(self, manufacturer_id, **kwargs):
+        """Update manufacturer
+
+        :param manufacturer_id: manufacturer to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/manufacturer/', manufacturer_id, **kwargs)
+
     def delete_manufacturer(self, manufacturer_name):
         """Delete manufacturer
 
@@ -373,6 +501,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('manufacturer: {}'.format(manufacturer_name)) from None
         return self.netbox_con.delete('/dcim/manufacturers/', manufacturer_id)
 
+    def delete_manufacturer_id(self, manufacturer_id):
+        """Delete manufacturer
+
+        :param manufacturer_id: manufacturer to delete
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.delete('/dcim/manufacturers/', manufacturer_id)
+
     def get_platforms(self, **kwargs):
         """Return all platforms"""
         return self.netbox_con.get('/dcim/platforms', **kwargs)
@@ -401,6 +537,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('platform: {}'.format(platform_name)) from None
         return self.netbox_con.patch('/dcim/platforms/', platform_id, **kwargs)
 
+    def update_platform_by_id(self, platform_id, **kwargs):
+        """Update platform
+
+        :param platform_id: platform to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/platforms/', platform_id, **kwargs)
+
     def delete_platform(self, platform_name):
         """Delete platform
 
@@ -413,6 +558,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('platform: {}'.format(platform_name)) from None
         return self.netbox_con.delete('/dcim/platforms/', platform_id)
 
+    def delete_platform_by_id(self, platform_id):
+        """Delete platform
+
+        :param platform_id: platform to delete
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.delete('/dcim/platforms/', platform_id)
+
     def get_interfaces(self, **kwargs):
         """Return interfaces"""
         return self.netbox_con.get('/dcim/interfaces', **kwargs)
@@ -443,6 +596,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('interface: {}'.format(interface)) from None
         return self.netbox_con.patch('/dcim/interfaces/', interface_id, **kwargs)
 
+    def update_interface_by_id(self, interface_id, **kwargs):
+        """Update interface
+
+        :param interface_id: interface to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/interfaces/', interface_id, **kwargs)
+
     def delete_interface(self, interface_name, device):
         """Delete interface
 
@@ -456,6 +618,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('interface: {}'.format(interface_name)) from None
         return self.netbox_con.delete('/dcim/interfaces/', interface_id)
 
+    def delete_interface_by_id(self, interface_id):
+        """Delete interface
+
+        :param interface_id: interface to delete
+        :return: bool True if successful otherwise raise DeleteException
+        """
+        return self.netbox_con.delete('/dcim/interfaces/', interface_id)
+
     def get_interface_connections(self, **kwargs):
         """Get interface connections
 
@@ -484,7 +654,7 @@ class Dcim(object):
         return self.netbox_con.delete('/dcim/interface-connections/', interface_connection_id)
 
     def update_interface_connection(self, interface_connection_id, **kwargs):
-        """Update interface
+        """Update interface connection
 
         :param interface_connection_id: interface_connection to update
         :param kwargs: requests body dict
@@ -499,7 +669,7 @@ class Dcim(object):
     def create_interface_template(self, name, device_type, **kwargs):
         """Create a new interface template
 
-        :param name: name of the interface
+        :param name: rack_grounamep_id of the interface
         :param kwargs: optional arguments
         :param device_type: name of the device_type to associate template with
         :return: netbox object if successful otherwise raise CreateException
@@ -524,6 +694,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('interface: {}'.format(interface_template_name)) from None
         return self.netbox_con.patch('/dcim/interface-templates/', interface_template_id, **kwargs)
 
+    def update_interface_template_by_id(self, interface_template_id, **kwargs):
+        """Update interface template
+
+        :param interface_template_id: interface template to update
+        :param kwargs: requests body dict
+        :return: bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/interface-templates/', interface_template_id, **kwargs)
+
     def delete_interface_template(self, interface_template_name):
         """Delete interface template
 
@@ -536,6 +715,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('interface-template: {}'.format(interface_template_name)) from None
         return self.netbox_con.delete('/dcim/interface-templates/', interface_template_id)
 
+    def delete_interface_template_by_id(self, interface_template_id):
+        """Delete interface template
+
+        :param interface_template_id: Name of interface template to delete
+        :return: bool True if successful otherwise raise DeleteException
+        """
+        return self.netbox_con.delete('/dcim/interface-templates/', interface_template_id)
+
     def get_inventory_items(self, **kwargs):
         """Return inventory items"""
         return self.netbox_con.get('/dcim/inventory-items/', **kwargs)
@@ -569,6 +756,15 @@ class Dcim(object):
             raise exceptions.NotFoundException('inventory item: {}'.format(name)) from None
         return self.netbox_con.patch('/dcim/inventory-items/', inventory_item_id, **kwargs)
 
+    def update_inventory_item_by_id(self, inventory_item_id, **kwargs):
+        """Update inventory item
+
+        :param inventory_item_id: Inventory item to delete
+        :param kwargs: Extra inventory items to update
+        :return bool True if successful otherwise raise Exception
+        """
+        return self.netbox_con.patch('/dcim/inventory-items/', inventory_item_id, **kwargs)
+
     def delete_inventory_item(self, name, device_name):
         """Delete inventory item
 
@@ -582,6 +778,14 @@ class Dcim(object):
             raise exceptions.NotFoundException('inventory item: {}'.format(name)) from None
         return self.netbox_con.delete('/dcim/inventory-items/', inventory_item_id)
 
+    def delete_inventory_item_by_id(self, inventory_item_id):
+        """Delete inventory item
+
+        :param inventory_item_id: Name of inventory item to delete
+        :return: bool True if successful otherwise raise DeleteException
+        """
+        return self.netbox_con.delete('/dcim/inventory-items/', inventory_item_id)
+
     def get_power_outlets(self, **kwargs):
         """Get power outlets matching optional kwarg filters"""
         return self.netbox_con.get('/dcim/power-outlets/', **kwargs)
